@@ -3,7 +3,8 @@ from __future__ import annotations
 from .deps import CONDA
 from dataclasses import dataclass
 from pathlib import Path
-from typing import List, Optional
+from typing import List
+from more_itertools import first
 
 
 @dataclass
@@ -36,6 +37,14 @@ class CondaEnvSpec:
         else:
             return Path((await conda_env_export(self))["prefix"])
 
+    def export_name(self):
+        if not self.is_prefix:
+            return self.name
+        else:
+            return first(
+                [p for p in reversed(Path(self.name).parts) if not p.startswith(".")]
+            )
+
 
 async def conda_env_export(env_spec: CondaEnvSpec):
     return await CONDA.json("env", "export", env_spec(), "--no-builds", "--json")
